# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from neurion.crucible import tx_pb2 as neurion_dot_crucible_dot_tx__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in neurion/crucible/tx_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class MsgStub(object):
    """Msg defines the Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.UpdateParams = channel.unary_unary(
                '/neurion.crucible.Msg/UpdateParams',
                request_serializer=neurion_dot_crucible_dot_tx__pb2.MsgUpdateParams.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgUpdateParamsResponse.FromString,
                _registered_method=True)
        self.ApplyCreator = channel.unary_unary(
                '/neurion.crucible.Msg/ApplyCreator',
                request_serializer=neurion_dot_crucible_dot_tx__pb2.MsgApplyCreator.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgApplyCreatorResponse.FromString,
                _registered_method=True)
        self.ApproveApplication = channel.unary_unary(
                '/neurion.crucible.Msg/ApproveApplication',
                request_serializer=neurion_dot_crucible_dot_tx__pb2.MsgApproveApplication.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgApproveApplicationResponse.FromString,
                _registered_method=True)
        self.RejectApplication = channel.unary_unary(
                '/neurion.crucible.Msg/RejectApplication',
                request_serializer=neurion_dot_crucible_dot_tx__pb2.MsgRejectApplication.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgRejectApplicationResponse.FromString,
                _registered_method=True)
        self.CreateTask = channel.unary_unary(
                '/neurion.crucible.Msg/CreateTask',
                request_serializer=neurion_dot_crucible_dot_tx__pb2.MsgCreateTask.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgCreateTaskResponse.FromString,
                _registered_method=True)
        self.RegisterTrainer = channel.unary_unary(
                '/neurion.crucible.Msg/RegisterTrainer',
                request_serializer=neurion_dot_crucible_dot_tx__pb2.MsgRegisterTrainer.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgRegisterTrainerResponse.FromString,
                _registered_method=True)
        self.RegisterScorer = channel.unary_unary(
                '/neurion.crucible.Msg/RegisterScorer',
                request_serializer=neurion_dot_crucible_dot_tx__pb2.MsgRegisterScorer.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgRegisterScorerResponse.FromString,
                _registered_method=True)
        self.SubmitTrainingResult = channel.unary_unary(
                '/neurion.crucible.Msg/SubmitTrainingResult',
                request_serializer=neurion_dot_crucible_dot_tx__pb2.MsgSubmitTrainingResult.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgSubmitTrainingResultResponse.FromString,
                _registered_method=True)
        self.StakeToTask = channel.unary_unary(
                '/neurion.crucible.Msg/StakeToTask',
                request_serializer=neurion_dot_crucible_dot_tx__pb2.MsgStakeToTask.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgStakeToTaskResponse.FromString,
                _registered_method=True)
        self.RequestScoringTask = channel.unary_unary(
                '/neurion.crucible.Msg/RequestScoringTask',
                request_serializer=neurion_dot_crucible_dot_tx__pb2.MsgRequestScoringTask.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgRequestScoringTaskResponse.FromString,
                _registered_method=True)
        self.SubmitScore = channel.unary_unary(
                '/neurion.crucible.Msg/SubmitScore',
                request_serializer=neurion_dot_crucible_dot_tx__pb2.MsgSubmitScore.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgSubmitScoreResponse.FromString,
                _registered_method=True)
        self.SubmitFinalResult = channel.unary_unary(
                '/neurion.crucible.Msg/SubmitFinalResult',
                request_serializer=neurion_dot_crucible_dot_tx__pb2.MsgSubmitFinalResult.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgSubmitFinalResultResponse.FromString,
                _registered_method=True)
        self.ReportModelPlagiarism = channel.unary_unary(
                '/neurion.crucible.Msg/ReportModelPlagiarism',
                request_serializer=neurion_dot_crucible_dot_tx__pb2.MsgReportModelPlagiarism.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgReportModelPlagiarismResponse.FromString,
                _registered_method=True)
        self.AcceptPlagiarismReport = channel.unary_unary(
                '/neurion.crucible.Msg/AcceptPlagiarismReport',
                request_serializer=neurion_dot_crucible_dot_tx__pb2.MsgAcceptPlagiarismReport.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgAcceptPlagiarismReportResponse.FromString,
                _registered_method=True)
        self.RejectPlagiarismReport = channel.unary_unary(
                '/neurion.crucible.Msg/RejectPlagiarismReport',
                request_serializer=neurion_dot_crucible_dot_tx__pb2.MsgRejectPlagiarismReport.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgRejectPlagiarismReportResponse.FromString,
                _registered_method=True)
        self.DisputeSubmissionScore = channel.unary_unary(
                '/neurion.crucible.Msg/DisputeSubmissionScore',
                request_serializer=neurion_dot_crucible_dot_tx__pb2.MsgDisputeSubmissionScore.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgDisputeSubmissionScoreResponse.FromString,
                _registered_method=True)
        self.StartTask = channel.unary_unary(
                '/neurion.crucible.Msg/StartTask',
                request_serializer=neurion_dot_crucible_dot_tx__pb2.MsgStartTask.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgStartTaskResponse.FromString,
                _registered_method=True)
        self.AbortTask = channel.unary_unary(
                '/neurion.crucible.Msg/AbortTask',
                request_serializer=neurion_dot_crucible_dot_tx__pb2.MsgAbortTask.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgAbortTaskResponse.FromString,
                _registered_method=True)
        self.TriggerTaskToFinalSubmission = channel.unary_unary(
                '/neurion.crucible.Msg/TriggerTaskToFinalSubmission',
                request_serializer=neurion_dot_crucible_dot_tx__pb2.MsgTriggerTaskToFinalSubmission.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgTriggerTaskToFinalSubmissionResponse.FromString,
                _registered_method=True)
        self.TriggerTaskToFinalTesting = channel.unary_unary(
                '/neurion.crucible.Msg/TriggerTaskToFinalTesting',
                request_serializer=neurion_dot_crucible_dot_tx__pb2.MsgTriggerTaskToFinalTesting.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgTriggerTaskToFinalTestingResponse.FromString,
                _registered_method=True)
        self.TerminateTask = channel.unary_unary(
                '/neurion.crucible.Msg/TerminateTask',
                request_serializer=neurion_dot_crucible_dot_tx__pb2.MsgTerminateTask.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgTerminateTaskResponse.FromString,
                _registered_method=True)
        self.ClaimTaskReward = channel.unary_unary(
                '/neurion.crucible.Msg/ClaimTaskReward',
                request_serializer=neurion_dot_crucible_dot_tx__pb2.MsgClaimTaskReward.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgClaimTaskRewardResponse.FromString,
                _registered_method=True)
        self.UnstakeFromTask = channel.unary_unary(
                '/neurion.crucible.Msg/UnstakeFromTask',
                request_serializer=neurion_dot_crucible_dot_tx__pb2.MsgUnstakeFromTask.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgUnstakeFromTaskResponse.FromString,
                _registered_method=True)
        self.DisclaimCreatorStatus = channel.unary_unary(
                '/neurion.crucible.Msg/DisclaimCreatorStatus',
                request_serializer=neurion_dot_crucible_dot_tx__pb2.MsgDisclaimCreatorStatus.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgDisclaimCreatorStatusResponse.FromString,
                _registered_method=True)


class MsgServicer(object):
    """Msg defines the Msg service.
    """

    def UpdateParams(self, request, context):
        """UpdateParams defines a (governance) operation for updating the module
        parameters. The authority defaults to the x/gov module account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ApplyCreator(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ApproveApplication(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RejectApplication(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateTask(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterTrainer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterScorer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubmitTrainingResult(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StakeToTask(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RequestScoringTask(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubmitScore(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubmitFinalResult(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReportModelPlagiarism(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AcceptPlagiarismReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RejectPlagiarismReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisputeSubmissionScore(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartTask(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AbortTask(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerTaskToFinalSubmission(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerTaskToFinalTesting(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TerminateTask(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClaimTaskReward(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnstakeFromTask(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisclaimCreatorStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'UpdateParams': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateParams,
                    request_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgUpdateParams.FromString,
                    response_serializer=neurion_dot_crucible_dot_tx__pb2.MsgUpdateParamsResponse.SerializeToString,
            ),
            'ApplyCreator': grpc.unary_unary_rpc_method_handler(
                    servicer.ApplyCreator,
                    request_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgApplyCreator.FromString,
                    response_serializer=neurion_dot_crucible_dot_tx__pb2.MsgApplyCreatorResponse.SerializeToString,
            ),
            'ApproveApplication': grpc.unary_unary_rpc_method_handler(
                    servicer.ApproveApplication,
                    request_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgApproveApplication.FromString,
                    response_serializer=neurion_dot_crucible_dot_tx__pb2.MsgApproveApplicationResponse.SerializeToString,
            ),
            'RejectApplication': grpc.unary_unary_rpc_method_handler(
                    servicer.RejectApplication,
                    request_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgRejectApplication.FromString,
                    response_serializer=neurion_dot_crucible_dot_tx__pb2.MsgRejectApplicationResponse.SerializeToString,
            ),
            'CreateTask': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTask,
                    request_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgCreateTask.FromString,
                    response_serializer=neurion_dot_crucible_dot_tx__pb2.MsgCreateTaskResponse.SerializeToString,
            ),
            'RegisterTrainer': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterTrainer,
                    request_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgRegisterTrainer.FromString,
                    response_serializer=neurion_dot_crucible_dot_tx__pb2.MsgRegisterTrainerResponse.SerializeToString,
            ),
            'RegisterScorer': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterScorer,
                    request_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgRegisterScorer.FromString,
                    response_serializer=neurion_dot_crucible_dot_tx__pb2.MsgRegisterScorerResponse.SerializeToString,
            ),
            'SubmitTrainingResult': grpc.unary_unary_rpc_method_handler(
                    servicer.SubmitTrainingResult,
                    request_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgSubmitTrainingResult.FromString,
                    response_serializer=neurion_dot_crucible_dot_tx__pb2.MsgSubmitTrainingResultResponse.SerializeToString,
            ),
            'StakeToTask': grpc.unary_unary_rpc_method_handler(
                    servicer.StakeToTask,
                    request_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgStakeToTask.FromString,
                    response_serializer=neurion_dot_crucible_dot_tx__pb2.MsgStakeToTaskResponse.SerializeToString,
            ),
            'RequestScoringTask': grpc.unary_unary_rpc_method_handler(
                    servicer.RequestScoringTask,
                    request_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgRequestScoringTask.FromString,
                    response_serializer=neurion_dot_crucible_dot_tx__pb2.MsgRequestScoringTaskResponse.SerializeToString,
            ),
            'SubmitScore': grpc.unary_unary_rpc_method_handler(
                    servicer.SubmitScore,
                    request_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgSubmitScore.FromString,
                    response_serializer=neurion_dot_crucible_dot_tx__pb2.MsgSubmitScoreResponse.SerializeToString,
            ),
            'SubmitFinalResult': grpc.unary_unary_rpc_method_handler(
                    servicer.SubmitFinalResult,
                    request_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgSubmitFinalResult.FromString,
                    response_serializer=neurion_dot_crucible_dot_tx__pb2.MsgSubmitFinalResultResponse.SerializeToString,
            ),
            'ReportModelPlagiarism': grpc.unary_unary_rpc_method_handler(
                    servicer.ReportModelPlagiarism,
                    request_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgReportModelPlagiarism.FromString,
                    response_serializer=neurion_dot_crucible_dot_tx__pb2.MsgReportModelPlagiarismResponse.SerializeToString,
            ),
            'AcceptPlagiarismReport': grpc.unary_unary_rpc_method_handler(
                    servicer.AcceptPlagiarismReport,
                    request_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgAcceptPlagiarismReport.FromString,
                    response_serializer=neurion_dot_crucible_dot_tx__pb2.MsgAcceptPlagiarismReportResponse.SerializeToString,
            ),
            'RejectPlagiarismReport': grpc.unary_unary_rpc_method_handler(
                    servicer.RejectPlagiarismReport,
                    request_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgRejectPlagiarismReport.FromString,
                    response_serializer=neurion_dot_crucible_dot_tx__pb2.MsgRejectPlagiarismReportResponse.SerializeToString,
            ),
            'DisputeSubmissionScore': grpc.unary_unary_rpc_method_handler(
                    servicer.DisputeSubmissionScore,
                    request_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgDisputeSubmissionScore.FromString,
                    response_serializer=neurion_dot_crucible_dot_tx__pb2.MsgDisputeSubmissionScoreResponse.SerializeToString,
            ),
            'StartTask': grpc.unary_unary_rpc_method_handler(
                    servicer.StartTask,
                    request_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgStartTask.FromString,
                    response_serializer=neurion_dot_crucible_dot_tx__pb2.MsgStartTaskResponse.SerializeToString,
            ),
            'AbortTask': grpc.unary_unary_rpc_method_handler(
                    servicer.AbortTask,
                    request_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgAbortTask.FromString,
                    response_serializer=neurion_dot_crucible_dot_tx__pb2.MsgAbortTaskResponse.SerializeToString,
            ),
            'TriggerTaskToFinalSubmission': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerTaskToFinalSubmission,
                    request_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgTriggerTaskToFinalSubmission.FromString,
                    response_serializer=neurion_dot_crucible_dot_tx__pb2.MsgTriggerTaskToFinalSubmissionResponse.SerializeToString,
            ),
            'TriggerTaskToFinalTesting': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerTaskToFinalTesting,
                    request_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgTriggerTaskToFinalTesting.FromString,
                    response_serializer=neurion_dot_crucible_dot_tx__pb2.MsgTriggerTaskToFinalTestingResponse.SerializeToString,
            ),
            'TerminateTask': grpc.unary_unary_rpc_method_handler(
                    servicer.TerminateTask,
                    request_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgTerminateTask.FromString,
                    response_serializer=neurion_dot_crucible_dot_tx__pb2.MsgTerminateTaskResponse.SerializeToString,
            ),
            'ClaimTaskReward': grpc.unary_unary_rpc_method_handler(
                    servicer.ClaimTaskReward,
                    request_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgClaimTaskReward.FromString,
                    response_serializer=neurion_dot_crucible_dot_tx__pb2.MsgClaimTaskRewardResponse.SerializeToString,
            ),
            'UnstakeFromTask': grpc.unary_unary_rpc_method_handler(
                    servicer.UnstakeFromTask,
                    request_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgUnstakeFromTask.FromString,
                    response_serializer=neurion_dot_crucible_dot_tx__pb2.MsgUnstakeFromTaskResponse.SerializeToString,
            ),
            'DisclaimCreatorStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.DisclaimCreatorStatus,
                    request_deserializer=neurion_dot_crucible_dot_tx__pb2.MsgDisclaimCreatorStatus.FromString,
                    response_serializer=neurion_dot_crucible_dot_tx__pb2.MsgDisclaimCreatorStatusResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'neurion.crucible.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('neurion.crucible.Msg', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the Msg service.
    """

    @staticmethod
    def UpdateParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Msg/UpdateParams',
            neurion_dot_crucible_dot_tx__pb2.MsgUpdateParams.SerializeToString,
            neurion_dot_crucible_dot_tx__pb2.MsgUpdateParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ApplyCreator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Msg/ApplyCreator',
            neurion_dot_crucible_dot_tx__pb2.MsgApplyCreator.SerializeToString,
            neurion_dot_crucible_dot_tx__pb2.MsgApplyCreatorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ApproveApplication(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Msg/ApproveApplication',
            neurion_dot_crucible_dot_tx__pb2.MsgApproveApplication.SerializeToString,
            neurion_dot_crucible_dot_tx__pb2.MsgApproveApplicationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RejectApplication(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Msg/RejectApplication',
            neurion_dot_crucible_dot_tx__pb2.MsgRejectApplication.SerializeToString,
            neurion_dot_crucible_dot_tx__pb2.MsgRejectApplicationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Msg/CreateTask',
            neurion_dot_crucible_dot_tx__pb2.MsgCreateTask.SerializeToString,
            neurion_dot_crucible_dot_tx__pb2.MsgCreateTaskResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RegisterTrainer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Msg/RegisterTrainer',
            neurion_dot_crucible_dot_tx__pb2.MsgRegisterTrainer.SerializeToString,
            neurion_dot_crucible_dot_tx__pb2.MsgRegisterTrainerResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RegisterScorer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Msg/RegisterScorer',
            neurion_dot_crucible_dot_tx__pb2.MsgRegisterScorer.SerializeToString,
            neurion_dot_crucible_dot_tx__pb2.MsgRegisterScorerResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SubmitTrainingResult(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Msg/SubmitTrainingResult',
            neurion_dot_crucible_dot_tx__pb2.MsgSubmitTrainingResult.SerializeToString,
            neurion_dot_crucible_dot_tx__pb2.MsgSubmitTrainingResultResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StakeToTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Msg/StakeToTask',
            neurion_dot_crucible_dot_tx__pb2.MsgStakeToTask.SerializeToString,
            neurion_dot_crucible_dot_tx__pb2.MsgStakeToTaskResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RequestScoringTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Msg/RequestScoringTask',
            neurion_dot_crucible_dot_tx__pb2.MsgRequestScoringTask.SerializeToString,
            neurion_dot_crucible_dot_tx__pb2.MsgRequestScoringTaskResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SubmitScore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Msg/SubmitScore',
            neurion_dot_crucible_dot_tx__pb2.MsgSubmitScore.SerializeToString,
            neurion_dot_crucible_dot_tx__pb2.MsgSubmitScoreResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SubmitFinalResult(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Msg/SubmitFinalResult',
            neurion_dot_crucible_dot_tx__pb2.MsgSubmitFinalResult.SerializeToString,
            neurion_dot_crucible_dot_tx__pb2.MsgSubmitFinalResultResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ReportModelPlagiarism(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Msg/ReportModelPlagiarism',
            neurion_dot_crucible_dot_tx__pb2.MsgReportModelPlagiarism.SerializeToString,
            neurion_dot_crucible_dot_tx__pb2.MsgReportModelPlagiarismResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AcceptPlagiarismReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Msg/AcceptPlagiarismReport',
            neurion_dot_crucible_dot_tx__pb2.MsgAcceptPlagiarismReport.SerializeToString,
            neurion_dot_crucible_dot_tx__pb2.MsgAcceptPlagiarismReportResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RejectPlagiarismReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Msg/RejectPlagiarismReport',
            neurion_dot_crucible_dot_tx__pb2.MsgRejectPlagiarismReport.SerializeToString,
            neurion_dot_crucible_dot_tx__pb2.MsgRejectPlagiarismReportResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DisputeSubmissionScore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Msg/DisputeSubmissionScore',
            neurion_dot_crucible_dot_tx__pb2.MsgDisputeSubmissionScore.SerializeToString,
            neurion_dot_crucible_dot_tx__pb2.MsgDisputeSubmissionScoreResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StartTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Msg/StartTask',
            neurion_dot_crucible_dot_tx__pb2.MsgStartTask.SerializeToString,
            neurion_dot_crucible_dot_tx__pb2.MsgStartTaskResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AbortTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Msg/AbortTask',
            neurion_dot_crucible_dot_tx__pb2.MsgAbortTask.SerializeToString,
            neurion_dot_crucible_dot_tx__pb2.MsgAbortTaskResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TriggerTaskToFinalSubmission(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Msg/TriggerTaskToFinalSubmission',
            neurion_dot_crucible_dot_tx__pb2.MsgTriggerTaskToFinalSubmission.SerializeToString,
            neurion_dot_crucible_dot_tx__pb2.MsgTriggerTaskToFinalSubmissionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TriggerTaskToFinalTesting(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Msg/TriggerTaskToFinalTesting',
            neurion_dot_crucible_dot_tx__pb2.MsgTriggerTaskToFinalTesting.SerializeToString,
            neurion_dot_crucible_dot_tx__pb2.MsgTriggerTaskToFinalTestingResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TerminateTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Msg/TerminateTask',
            neurion_dot_crucible_dot_tx__pb2.MsgTerminateTask.SerializeToString,
            neurion_dot_crucible_dot_tx__pb2.MsgTerminateTaskResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ClaimTaskReward(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Msg/ClaimTaskReward',
            neurion_dot_crucible_dot_tx__pb2.MsgClaimTaskReward.SerializeToString,
            neurion_dot_crucible_dot_tx__pb2.MsgClaimTaskRewardResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UnstakeFromTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Msg/UnstakeFromTask',
            neurion_dot_crucible_dot_tx__pb2.MsgUnstakeFromTask.SerializeToString,
            neurion_dot_crucible_dot_tx__pb2.MsgUnstakeFromTaskResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DisclaimCreatorStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Msg/DisclaimCreatorStatus',
            neurion_dot_crucible_dot_tx__pb2.MsgDisclaimCreatorStatus.SerializeToString,
            neurion_dot_crucible_dot_tx__pb2.MsgDisclaimCreatorStatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/base/store/v1beta1/snapshot.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/base/store/v1beta1/snapshot.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(cosmos/base/store/v1beta1/snapshot.proto\x12\x19\x63osmos.base.store.v1beta1\x1a\x14gogoproto/gogo.proto\"\x9c\x01\n\x0cSnapshotItem\x12=\n\x05store\x18\x01 \x01(\x0b\x32,.cosmos.base.store.v1beta1.SnapshotStoreItemH\x00\x12\x45\n\x04iavl\x18\x02 \x01(\x0b\x32+.cosmos.base.store.v1beta1.SnapshotIAVLItemB\x08\xe2\xde\x1f\x04IAVLH\x00\x42\x06\n\x04item\"!\n\x11SnapshotStoreItem\x12\x0c\n\x04name\x18\x01 \x01(\t\"O\n\x10SnapshotIAVLItem\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\x0f\n\x07version\x18\x03 \x01(\x03\x12\x0e\n\x06height\x18\x04 \x01(\x05\x42*Z(github.com/cosmos/cosmos-sdk/store/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.store.v1beta1.snapshot_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z(github.com/cosmos/cosmos-sdk/store/types'
  _globals['_SNAPSHOTITEM'].fields_by_name['iavl']._loaded_options = None
  _globals['_SNAPSHOTITEM'].fields_by_name['iavl']._serialized_options = b'\342\336\037\004IAVL'
  _globals['_SNAPSHOTITEM']._serialized_start=94
  _globals['_SNAPSHOTITEM']._serialized_end=250
  _globals['_SNAPSHOTSTOREITEM']._serialized_start=252
  _globals['_SNAPSHOTSTOREITEM']._serialized_end=285
  _globals['_SNAPSHOTIAVLITEM']._serialized_start=287
  _globals['_SNAPSHOTIAVLITEM']._serialized_end=366
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/fusion/params.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/fusion/params.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from amino import amino_pb2 as amino_dot_amino__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bneurion/fusion/params.proto\x12\x0eneurion.fusion\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\"\xba\x04\n\x06Params\x12\x15\n\radmin_address\x18\x01 \x01(\t\x12\x17\n\x0fmin_task_reward\x18\x02 \x01(\x04\x12\x1f\n\x17min_task_proposer_stake\x18\x04 \x01(\x04\x12 \n\x18min_task_validator_stake\x18\x05 \x01(\x04\x12(\n min_proposal_duration_in_seconds\x18\x06 \x01(\x04\x12\'\n\x1fmin_dispute_duration_in_seconds\x18\x07 \x01(\x04\x12\x19\n\x11min_creator_stake\x18\x08 \x01(\x04\x12\x1f\n\x17\x63reator_application_fee\x18\t \x01(\x04\x12 \n\x18\x64ispute_validator_reward\x18\n \x01(\x04\x12!\n\x19min_dispute_score_deposit\x18\x0b \x01(\x04\x12\x1d\n\x15\x66irst_proposer_weight\x18\x0c \x01(\x04\x12\x1e\n\x16second_proposer_weight\x18\r \x01(\x04\x12\x1d\n\x15third_proposer_weight\x18\x0e \x01(\x04\x12\"\n\x1aproposer_reward_percentage\x18\x0f \x01(\x04\x12#\n\x1bvalidator_reward_percentage\x18\x10 \x01(\x04\x12 \n\x18staker_reward_percentage\x18\x11 \x01(\x04: \xe8\xa0\x1f\x01\x8a\xe7\xb0*\x17neurion/x/fusion/ParamsB\x18Z\x16neurion/x/fusion/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.fusion.params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\026neurion/x/fusion/types'
  _globals['_PARAMS']._loaded_options = None
  _globals['_PARAMS']._serialized_options = b'\350\240\037\001\212\347\260*\027neurion/x/fusion/Params'
  _globals['_PARAMS']._serialized_start=89
  _globals['_PARAMS']._serialized_end=659
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/types/v1beta1/events.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/types/v1beta1/events.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cometbft/types/v1beta1/events.proto\x12\x16\x63ometbft.types.v1beta1\"B\n\x13\x45ventDataRoundState\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12\x0c\n\x04step\x18\x03 \x01(\tB9Z7github.com/cometbft/cometbft/api/cometbft/types/v1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.types.v1beta1.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/cometbft/cometbft/api/cometbft/types/v1beta1'
  _globals['_EVENTDATAROUNDSTATE']._serialized_start=63
  _globals['_EVENTDATAROUNDSTATE']._serialized_end=129
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class SetBlockRetainHeightRequest(_message.Message):
    __slots__ = ("height",)
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    height: int
    def __init__(self, height: _Optional[int] = ...) -> None: ...

class SetBlockRetainHeightResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetBlockRetainHeightRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetBlockRetainHeightResponse(_message.Message):
    __slots__ = ("app_retain_height", "pruning_service_retain_height")
    APP_RETAIN_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    PRUNING_SERVICE_RETAIN_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    app_retain_height: int
    pruning_service_retain_height: int
    def __init__(self, app_retain_height: _Optional[int] = ..., pruning_service_retain_height: _Optional[int] = ...) -> None: ...

class SetBlockResultsRetainHeightRequest(_message.Message):
    __slots__ = ("height",)
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    height: int
    def __init__(self, height: _Optional[int] = ...) -> None: ...

class SetBlockResultsRetainHeightResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetBlockResultsRetainHeightRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetBlockResultsRetainHeightResponse(_message.Message):
    __slots__ = ("pruning_service_retain_height",)
    PRUNING_SERVICE_RETAIN_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    pruning_service_retain_height: int
    def __init__(self, pruning_service_retain_height: _Optional[int] = ...) -> None: ...

class SetTxIndexerRetainHeightRequest(_message.Message):
    __slots__ = ("height",)
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    height: int
    def __init__(self, height: _Optional[int] = ...) -> None: ...

class SetTxIndexerRetainHeightResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetTxIndexerRetainHeightRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetTxIndexerRetainHeightResponse(_message.Message):
    __slots__ = ("height",)
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    height: int
    def __init__(self, height: _Optional[int] = ...) -> None: ...

class SetBlockIndexerRetainHeightRequest(_message.Message):
    __slots__ = ("height",)
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    height: int
    def __init__(self, height: _Optional[int] = ...) -> None: ...

class SetBlockIndexerRetainHeightResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetBlockIndexerRetainHeightRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetBlockIndexerRetainHeightResponse(_message.Message):
    __slots__ = ("height",)
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    height: int
    def __init__(self, height: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/state/v1beta1/types.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/state/v1beta1/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cometbft.abci.v1beta1 import types_pb2 as cometbft_dot_abci_dot_v1beta1_dot_types__pb2
from cometbft.types.v1beta1 import types_pb2 as cometbft_dot_types_dot_v1beta1_dot_types__pb2
from cometbft.types.v1beta1 import validator_pb2 as cometbft_dot_types_dot_v1beta1_dot_validator__pb2
from cometbft.types.v1beta1 import params_pb2 as cometbft_dot_types_dot_v1beta1_dot_params__pb2
from cometbft.version.v1 import types_pb2 as cometbft_dot_version_dot_v1_dot_types__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"cometbft/state/v1beta1/types.proto\x12\x16\x63ometbft.state.v1beta1\x1a\x14gogoproto/gogo.proto\x1a!cometbft/abci/v1beta1/types.proto\x1a\"cometbft/types/v1beta1/types.proto\x1a&cometbft/types/v1beta1/validator.proto\x1a#cometbft/types/v1beta1/params.proto\x1a\x1f\x63ometbft/version/v1/types.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xca\x01\n\rABCIResponses\x12=\n\x0b\x64\x65liver_txs\x18\x01 \x03(\x0b\x32(.cometbft.abci.v1beta1.ResponseDeliverTx\x12:\n\tend_block\x18\x02 \x01(\x0b\x32\'.cometbft.abci.v1beta1.ResponseEndBlock\x12>\n\x0b\x62\x65gin_block\x18\x03 \x01(\x0b\x32).cometbft.abci.v1beta1.ResponseBeginBlock\"j\n\x0eValidatorsInfo\x12;\n\rvalidator_set\x18\x01 \x01(\x0b\x32$.cometbft.types.v1beta1.ValidatorSet\x12\x1b\n\x13last_height_changed\x18\x02 \x01(\x03\"{\n\x13\x43onsensusParamsInfo\x12G\n\x10\x63onsensus_params\x18\x01 \x01(\x0b\x32\'.cometbft.types.v1beta1.ConsensusParamsB\x04\xc8\xde\x1f\x00\x12\x1b\n\x13last_height_changed\x18\x02 \x01(\x03\"b\n\x11\x41\x42\x43IResponsesInfo\x12=\n\x0e\x61\x62\x63i_responses\x18\x01 \x01(\x0b\x32%.cometbft.state.v1beta1.ABCIResponses\x12\x0e\n\x06height\x18\x02 \x01(\x03\"T\n\x07Version\x12\x37\n\tconsensus\x18\x01 \x01(\x0b\x32\x1e.cometbft.version.v1.ConsensusB\x04\xc8\xde\x1f\x00\x12\x10\n\x08software\x18\x02 \x01(\t\"\xa1\x05\n\x05State\x12\x36\n\x07version\x18\x01 \x01(\x0b\x32\x1f.cometbft.state.v1beta1.VersionB\x04\xc8\xde\x1f\x00\x12\x1d\n\x08\x63hain_id\x18\x02 \x01(\tB\x0b\xe2\xde\x1f\x07\x43hainID\x12\x16\n\x0einitial_height\x18\x0e \x01(\x03\x12\x19\n\x11last_block_height\x18\x03 \x01(\x03\x12K\n\rlast_block_id\x18\x04 \x01(\x0b\x32\x1f.cometbft.types.v1beta1.BlockIDB\x13\xc8\xde\x1f\x00\xe2\xde\x1f\x0bLastBlockID\x12=\n\x0flast_block_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12=\n\x0fnext_validators\x18\x06 \x01(\x0b\x32$.cometbft.types.v1beta1.ValidatorSet\x12\x38\n\nvalidators\x18\x07 \x01(\x0b\x32$.cometbft.types.v1beta1.ValidatorSet\x12=\n\x0flast_validators\x18\x08 \x01(\x0b\x32$.cometbft.types.v1beta1.ValidatorSet\x12&\n\x1elast_height_validators_changed\x18\t \x01(\x03\x12G\n\x10\x63onsensus_params\x18\n \x01(\x0b\x32\'.cometbft.types.v1beta1.ConsensusParamsB\x04\xc8\xde\x1f\x00\x12,\n$last_height_consensus_params_changed\x18\x0b \x01(\x03\x12\x19\n\x11last_results_hash\x18\x0c \x01(\x0c\x12\x10\n\x08\x61pp_hash\x18\r \x01(\x0c\x42\x39Z7github.com/cometbft/cometbft/api/cometbft/state/v1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.state.v1beta1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/cometbft/cometbft/api/cometbft/state/v1beta1'
  _globals['_CONSENSUSPARAMSINFO'].fields_by_name['consensus_params']._loaded_options = None
  _globals['_CONSENSUSPARAMSINFO'].fields_by_name['consensus_params']._serialized_options = b'\310\336\037\000'
  _globals['_VERSION'].fields_by_name['consensus']._loaded_options = None
  _globals['_VERSION'].fields_by_name['consensus']._serialized_options = b'\310\336\037\000'
  _globals['_STATE'].fields_by_name['version']._loaded_options = None
  _globals['_STATE'].fields_by_name['version']._serialized_options = b'\310\336\037\000'
  _globals['_STATE'].fields_by_name['chain_id']._loaded_options = None
  _globals['_STATE'].fields_by_name['chain_id']._serialized_options = b'\342\336\037\007ChainID'
  _globals['_STATE'].fields_by_name['last_block_id']._loaded_options = None
  _globals['_STATE'].fields_by_name['last_block_id']._serialized_options = b'\310\336\037\000\342\336\037\013LastBlockID'
  _globals['_STATE'].fields_by_name['last_block_time']._loaded_options = None
  _globals['_STATE'].fields_by_name['last_block_time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_STATE'].fields_by_name['consensus_params']._loaded_options = None
  _globals['_STATE'].fields_by_name['consensus_params']._serialized_options = b'\310\336\037\000'
  _globals['_ABCIRESPONSES']._serialized_start=299
  _globals['_ABCIRESPONSES']._serialized_end=501
  _globals['_VALIDATORSINFO']._serialized_start=503
  _globals['_VALIDATORSINFO']._serialized_end=609
  _globals['_CONSENSUSPARAMSINFO']._serialized_start=611
  _globals['_CONSENSUSPARAMSINFO']._serialized_end=734
  _globals['_ABCIRESPONSESINFO']._serialized_start=736
  _globals['_ABCIRESPONSESINFO']._serialized_end=834
  _globals['_VERSION']._serialized_start=836
  _globals['_VERSION']._serialized_end=920
  _globals['_STATE']._serialized_start=923
  _globals['_STATE']._serialized_end=1596
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/base/snapshots/v1beta1/snapshot.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/base/snapshots/v1beta1/snapshot.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,cosmos/base/snapshots/v1beta1/snapshot.proto\x12\x1d\x63osmos.base.snapshots.v1beta1\x1a\x14gogoproto/gogo.proto\"\x89\x01\n\x08Snapshot\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\r\x12\x0e\n\x06\x63hunks\x18\x03 \x01(\r\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\x12?\n\x08metadata\x18\x05 \x01(\x0b\x32\'.cosmos.base.snapshots.v1beta1.MetadataB\x04\xc8\xde\x1f\x00\" \n\x08Metadata\x12\x14\n\x0c\x63hunk_hashes\x18\x01 \x03(\x0c\x42.Z,github.com/cosmos/cosmos-sdk/snapshots/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.snapshots.v1beta1.snapshot_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z,github.com/cosmos/cosmos-sdk/snapshots/types'
  _globals['_SNAPSHOT'].fields_by_name['metadata']._loaded_options = None
  _globals['_SNAPSHOT'].fields_by_name['metadata']._serialized_options = b'\310\336\037\000'
  _globals['_SNAPSHOT']._serialized_start=102
  _globals['_SNAPSHOT']._serialized_end=239
  _globals['_METADATA']._serialized_start=241
  _globals['_METADATA']._serialized_end=273
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Ion(_message.Message):
    __slots__ = ("id", "creator", "stake", "endpoints", "available", "capacities", "description", "slashed_times", "input_schema", "output_schema", "input_schema_hash", "output_schema_hash", "fee_per_thousand_calls", "allowed_pathway_owners", "private")
    ID_FIELD_NUMBER: _ClassVar[int]
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    STAKE_FIELD_NUMBER: _ClassVar[int]
    ENDPOINTS_FIELD_NUMBER: _ClassVar[int]
    AVAILABLE_FIELD_NUMBER: _ClassVar[int]
    CAPACITIES_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    SLASHED_TIMES_FIELD_NUMBER: _ClassVar[int]
    INPUT_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    INPUT_SCHEMA_HASH_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_SCHEMA_HASH_FIELD_NUMBER: _ClassVar[int]
    FEE_PER_THOUSAND_CALLS_FIELD_NUMBER: _ClassVar[int]
    ALLOWED_PATHWAY_OWNERS_FIELD_NUMBER: _ClassVar[int]
    PRIVATE_FIELD_NUMBER: _ClassVar[int]
    id: int
    creator: str
    stake: int
    endpoints: _containers.RepeatedScalarFieldContainer[str]
    available: bool
    capacities: _containers.RepeatedScalarFieldContainer[str]
    description: str
    slashed_times: int
    input_schema: str
    output_schema: str
    input_schema_hash: str
    output_schema_hash: str
    fee_per_thousand_calls: int
    allowed_pathway_owners: _containers.RepeatedScalarFieldContainer[str]
    private: bool
    def __init__(self, id: _Optional[int] = ..., creator: _Optional[str] = ..., stake: _Optional[int] = ..., endpoints: _Optional[_Iterable[str]] = ..., available: bool = ..., capacities: _Optional[_Iterable[str]] = ..., description: _Optional[str] = ..., slashed_times: _Optional[int] = ..., input_schema: _Optional[str] = ..., output_schema: _Optional[str] = ..., input_schema_hash: _Optional[str] = ..., output_schema_hash: _Optional[str] = ..., fee_per_thousand_calls: _Optional[int] = ..., allowed_pathway_owners: _Optional[_Iterable[str]] = ..., private: bool = ...) -> None: ...



from amino import amino_pb2 as _amino_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.api import annotations_pb2 as _annotations_pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from neurion.ganglion import params_pb2 as _params_pb2
from neurion.ganglion import ion_pb2 as _ion_pb2
from neurion.ganglion import pathway_pb2 as _pathway_pb2
from neurion.ganglion import pathway_user_pb2 as _pathway_user_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryParamsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryParamsResponse(_message.Message):
    __slots__ = ("params",)
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _params_pb2.Params
    def __init__(self, params: _Optional[_Union[_params_pb2.Params, _Mapping]] = ...) -> None: ...

class QueryIonByIonAddressRequest(_message.Message):
    __slots__ = ("ion_address",)
    ION_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    ion_address: str
    def __init__(self, ion_address: _Optional[str] = ...) -> None: ...

class QueryIonByIonAddressResponse(_message.Message):
    __slots__ = ("ion",)
    ION_FIELD_NUMBER: _ClassVar[int]
    ion: _ion_pb2.Ion
    def __init__(self, ion: _Optional[_Union[_ion_pb2.Ion, _Mapping]] = ...) -> None: ...

class QueryIonByCreatorRequest(_message.Message):
    __slots__ = ("creator",)
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    creator: str
    def __init__(self, creator: _Optional[str] = ...) -> None: ...

class QueryIonByCreatorResponse(_message.Message):
    __slots__ = ("ion",)
    ION_FIELD_NUMBER: _ClassVar[int]
    ion: _ion_pb2.Ion
    def __init__(self, ion: _Optional[_Union[_ion_pb2.Ion, _Mapping]] = ...) -> None: ...

class QueryGetValidatorsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryGetValidatorsResponse(_message.Message):
    __slots__ = ("validators",)
    VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    validators: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, validators: _Optional[_Iterable[str]] = ...) -> None: ...

class QueryIonsByInputSchemaHashRequest(_message.Message):
    __slots__ = ("input_schema_hash", "user", "offset", "limit")
    INPUT_SCHEMA_HASH_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    input_schema_hash: str
    user: str
    offset: int
    limit: int
    def __init__(self, input_schema_hash: _Optional[str] = ..., user: _Optional[str] = ..., offset: _Optional[int] = ..., limit: _Optional[int] = ...) -> None: ...

class QueryIonsByInputSchemaHashResponse(_message.Message):
    __slots__ = ("ions", "pagination")
    IONS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    ions: _containers.RepeatedCompositeFieldContainer[_ion_pb2.Ion]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, ions: _Optional[_Iterable[_Union[_ion_pb2.Ion, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryGetPathwayRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: int
    def __init__(self, id: _Optional[int] = ...) -> None: ...

class QueryGetPathwayResponse(_message.Message):
    __slots__ = ("pathway",)
    PATHWAY_FIELD_NUMBER: _ClassVar[int]
    pathway: _pathway_pb2.Pathway
    def __init__(self, pathway: _Optional[_Union[_pathway_pb2.Pathway, _Mapping]] = ...) -> None: ...

class QueryListPathwaysRequest(_message.Message):
    __slots__ = ("creator", "offset", "limit")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    creator: str
    offset: int
    limit: int
    def __init__(self, creator: _Optional[str] = ..., offset: _Optional[int] = ..., limit: _Optional[int] = ...) -> None: ...

class QueryListPathwaysResponse(_message.Message):
    __slots__ = ("pathways", "pagination")
    PATHWAYS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pathways: _containers.RepeatedCompositeFieldContainer[_pathway_pb2.Pathway]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, pathways: _Optional[_Iterable[_Union[_pathway_pb2.Pathway, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryListIonsByAddressesRequest(_message.Message):
    __slots__ = ("ion_addresses",)
    ION_ADDRESSES_FIELD_NUMBER: _ClassVar[int]
    ion_addresses: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, ion_addresses: _Optional[_Iterable[str]] = ...) -> None: ...

class QueryListIonsByAddressesResponse(_message.Message):
    __slots__ = ("ions",)
    IONS_FIELD_NUMBER: _ClassVar[int]
    ions: _containers.RepeatedCompositeFieldContainer[_ion_pb2.Ion]
    def __init__(self, ions: _Optional[_Iterable[_Union[_ion_pb2.Ion, _Mapping]]] = ...) -> None: ...

class QueryUserPathwayStakeRequest(_message.Message):
    __slots__ = ("id", "user")
    ID_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    id: int
    user: str
    def __init__(self, id: _Optional[int] = ..., user: _Optional[str] = ...) -> None: ...

class QueryUserPathwayStakeResponse(_message.Message):
    __slots__ = ("stake",)
    STAKE_FIELD_NUMBER: _ClassVar[int]
    stake: int
    def __init__(self, stake: _Optional[int] = ...) -> None: ...

class QueryGetUserRewardRequest(_message.Message):
    __slots__ = ("user",)
    USER_FIELD_NUMBER: _ClassVar[int]
    user: str
    def __init__(self, user: _Optional[str] = ...) -> None: ...

class QueryGetUserRewardResponse(_message.Message):
    __slots__ = ("reward",)
    REWARD_FIELD_NUMBER: _ClassVar[int]
    reward: int
    def __init__(self, reward: _Optional[int] = ...) -> None: ...

class QueryGetProtocolFeeRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryGetProtocolFeeResponse(_message.Message):
    __slots__ = ("fee",)
    FEE_FIELD_NUMBER: _ClassVar[int]
    fee: int
    def __init__(self, fee: _Optional[int] = ...) -> None: ...

class QueryPathwaysUsingIonRequest(_message.Message):
    __slots__ = ("ion_address",)
    ION_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    ion_address: str
    def __init__(self, ion_address: _Optional[str] = ...) -> None: ...

class QueryPathwaysUsingIonResponse(_message.Message):
    __slots__ = ("pathways",)
    PATHWAYS_FIELD_NUMBER: _ClassVar[int]
    pathways: _containers.RepeatedCompositeFieldContainer[_pathway_pb2.Pathway]
    def __init__(self, pathways: _Optional[_Iterable[_Union[_pathway_pb2.Pathway, _Mapping]]] = ...) -> None: ...

class QueryIonsByReportsRequest(_message.Message):
    __slots__ = ("offset", "limit")
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    offset: int
    limit: int
    def __init__(self, offset: _Optional[int] = ..., limit: _Optional[int] = ...) -> None: ...

class QueryIonsByReportsResponse(_message.Message):
    __slots__ = ("ion_addresses", "pagination")
    ION_ADDRESSES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    ion_addresses: _containers.RepeatedScalarFieldContainer[str]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, ion_addresses: _Optional[_Iterable[str]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryListAllPathwaysRequest(_message.Message):
    __slots__ = ("offset", "limit")
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    offset: int
    limit: int
    def __init__(self, offset: _Optional[int] = ..., limit: _Optional[int] = ...) -> None: ...

class QueryListAllPathwaysResponse(_message.Message):
    __slots__ = ("pathways", "pagination")
    PATHWAYS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pathways: _containers.RepeatedCompositeFieldContainer[_pathway_pb2.Pathway]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, pathways: _Optional[_Iterable[_Union[_pathway_pb2.Pathway, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryGetRewardRequest(_message.Message):
    __slots__ = ("user",)
    USER_FIELD_NUMBER: _ClassVar[int]
    user: str
    def __init__(self, user: _Optional[str] = ...) -> None: ...

class QueryGetRewardResponse(_message.Message):
    __slots__ = ("reward",)
    REWARD_FIELD_NUMBER: _ClassVar[int]
    reward: int
    def __init__(self, reward: _Optional[int] = ...) -> None: ...

class QueryGetStakeRequest(_message.Message):
    __slots__ = ("user",)
    USER_FIELD_NUMBER: _ClassVar[int]
    user: str
    def __init__(self, user: _Optional[str] = ...) -> None: ...

class QueryGetStakeResponse(_message.Message):
    __slots__ = ("stake",)
    STAKE_FIELD_NUMBER: _ClassVar[int]
    stake: int
    def __init__(self, stake: _Optional[int] = ...) -> None: ...

class QueryGetIonRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: int
    def __init__(self, id: _Optional[int] = ...) -> None: ...

class QueryGetIonResponse(_message.Message):
    __slots__ = ("ion",)
    ION_FIELD_NUMBER: _ClassVar[int]
    ion: _ion_pb2.Ion
    def __init__(self, ion: _Optional[_Union[_ion_pb2.Ion, _Mapping]] = ...) -> None: ...

class QueryGetPathwayUnstakeInitiatedUsersRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryGetPathwayUnstakeInitiatedUsersResponse(_message.Message):
    __slots__ = ("pathway_users",)
    PATHWAY_USERS_FIELD_NUMBER: _ClassVar[int]
    pathway_users: _containers.RepeatedCompositeFieldContainer[_pathway_user_pb2.PathwayUser]
    def __init__(self, pathway_users: _Optional[_Iterable[_Union[_pathway_user_pb2.PathwayUser, _Mapping]]] = ...) -> None: ...

class QueryGetStakerRewardRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryGetStakerRewardResponse(_message.Message):
    __slots__ = ("reward",)
    REWARD_FIELD_NUMBER: _ClassVar[int]
    reward: int
    def __init__(self, reward: _Optional[int] = ...) -> None: ...

class QueryGetAvailableIonsRequest(_message.Message):
    __slots__ = ("user", "offset", "limit")
    USER_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    user: str
    offset: int
    limit: int
    def __init__(self, user: _Optional[str] = ..., offset: _Optional[int] = ..., limit: _Optional[int] = ...) -> None: ...

class QueryGetAvailableIonsResponse(_message.Message):
    __slots__ = ("ions", "pagination")
    IONS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    ions: _containers.RepeatedCompositeFieldContainer[_ion_pb2.Ion]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, ions: _Optional[_Iterable[_Union[_ion_pb2.Ion, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryValidateIonChainRequest(_message.Message):
    __slots__ = ("ion1", "ion2", "field_map_base64")
    ION1_FIELD_NUMBER: _ClassVar[int]
    ION2_FIELD_NUMBER: _ClassVar[int]
    FIELD_MAP_BASE64_FIELD_NUMBER: _ClassVar[int]
    ion1: str
    ion2: str
    field_map_base64: str
    def __init__(self, ion1: _Optional[str] = ..., ion2: _Optional[str] = ..., field_map_base64: _Optional[str] = ...) -> None: ...

class QueryValidateIonChainResponse(_message.Message):
    __slots__ = ("valid", "reason")
    VALID_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    valid: bool
    reason: str
    def __init__(self, valid: bool = ..., reason: _Optional[str] = ...) -> None: ...

class QueryGetAllowedIpsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryGetAllowedIpsResponse(_message.Message):
    __slots__ = ("ips",)
    IPS_FIELD_NUMBER: _ClassVar[int]
    ips: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, ips: _Optional[_Iterable[str]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class FungibleTokenPacketData(_message.Message):
    __slots__ = ("denom", "amount", "sender", "receiver")
    DENOM_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    SENDER_FIELD_NUMBER: _ClassVar[int]
    RECEIVER_FIELD_NUMBER: _ClassVar[int]
    denom: str
    amount: str
    sender: str
    receiver: str
    def __init__(self, denom: _Optional[str] = ..., amount: _Optional[str] = ..., sender: _Optional[str] = ..., receiver: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/bank/v1beta1/genesis.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/bank/v1beta1/genesis.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.bank.v1beta1 import bank_pb2 as cosmos_dot_bank_dot_v1beta1_dot_bank__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cosmos/bank/v1beta1/genesis.proto\x12\x13\x63osmos.bank.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1e\x63osmos/bank/v1beta1/bank.proto\"\xaa\x02\n\x0cGenesisState\x12\x31\n\x06params\x18\x01 \x01(\x0b\x32\x1b.cosmos.bank.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\x12\x34\n\x08\x62\x61lances\x18\x02 \x03(\x0b\x32\x1c.cosmos.bank.v1beta1.BalanceB\x04\xc8\xde\x1f\x00\x12[\n\x06supply\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12T\n\x0e\x64\x65nom_metadata\x18\x04 \x03(\x0b\x32\x1d.cosmos.bank.v1beta1.MetadataB\x1d\xc8\xde\x1f\x00\xf2\xde\x1f\x15yaml:\"denom_metadata\"\"\x80\x01\n\x07\x42\x61lance\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12Z\n\x05\x63oins\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x42+Z)github.com/cosmos/cosmos-sdk/x/bank/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.bank.v1beta1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/bank/types'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['balances']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['balances']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['supply']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['supply']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_GENESISSTATE'].fields_by_name['denom_metadata']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['denom_metadata']._serialized_options = b'\310\336\037\000\362\336\037\025yaml:\"denom_metadata\"'
  _globals['_BALANCE'].fields_by_name['coins']._loaded_options = None
  _globals['_BALANCE'].fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_BALANCE']._loaded_options = None
  _globals['_BALANCE']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_GENESISSTATE']._serialized_start=145
  _globals['_GENESISSTATE']._serialized_end=443
  _globals['_BALANCE']._serialized_start=446
  _globals['_BALANCE']._serialized_end=574
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Params(_message.Message):
    __slots__ = ("controller_enabled",)
    CONTROLLER_ENABLED_FIELD_NUMBER: _ClassVar[int]
    controller_enabled: bool
    def __init__(self, controller_enabled: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/slashing/v1beta1/genesis.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/slashing/v1beta1/genesis.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.slashing.v1beta1 import slashing_pb2 as cosmos_dot_slashing_dot_v1beta1_dot_slashing__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%cosmos/slashing/v1beta1/genesis.proto\x12\x17\x63osmos.slashing.v1beta1\x1a\x14gogoproto/gogo.proto\x1a&cosmos/slashing/v1beta1/slashing.proto\"\x85\x02\n\x0cGenesisState\x12\x35\n\x06params\x18\x01 \x01(\x0b\x32\x1f.cosmos.slashing.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\x12Y\n\rsigning_infos\x18\x02 \x03(\x0b\x32$.cosmos.slashing.v1beta1.SigningInfoB\x1c\xc8\xde\x1f\x00\xf2\xde\x1f\x14yaml:\"signing_infos\"\x12\x63\n\rmissed_blocks\x18\x03 \x03(\x0b\x32..cosmos.slashing.v1beta1.ValidatorMissedBlocksB\x1c\xc8\xde\x1f\x00\xf2\xde\x1f\x14yaml:\"missed_blocks\"\"\x94\x01\n\x0bSigningInfo\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12t\n\x16validator_signing_info\x18\x02 \x01(\x0b\x32-.cosmos.slashing.v1beta1.ValidatorSigningInfoB%\xc8\xde\x1f\x00\xf2\xde\x1f\x1dyaml:\"validator_signing_info\"\"\x83\x01\n\x15ValidatorMissedBlocks\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12Y\n\rmissed_blocks\x18\x02 \x03(\x0b\x32$.cosmos.slashing.v1beta1.MissedBlockB\x1c\xc8\xde\x1f\x00\xf2\xde\x1f\x14yaml:\"missed_blocks\"\",\n\x0bMissedBlock\x12\r\n\x05index\x18\x01 \x01(\x03\x12\x0e\n\x06missed\x18\x02 \x01(\x08\x42/Z-github.com/cosmos/cosmos-sdk/x/slashing/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.slashing.v1beta1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/cosmos/cosmos-sdk/x/slashing/types'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['signing_infos']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['signing_infos']._serialized_options = b'\310\336\037\000\362\336\037\024yaml:\"signing_infos\"'
  _globals['_GENESISSTATE'].fields_by_name['missed_blocks']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['missed_blocks']._serialized_options = b'\310\336\037\000\362\336\037\024yaml:\"missed_blocks\"'
  _globals['_SIGNINGINFO'].fields_by_name['validator_signing_info']._loaded_options = None
  _globals['_SIGNINGINFO'].fields_by_name['validator_signing_info']._serialized_options = b'\310\336\037\000\362\336\037\035yaml:\"validator_signing_info\"'
  _globals['_VALIDATORMISSEDBLOCKS'].fields_by_name['missed_blocks']._loaded_options = None
  _globals['_VALIDATORMISSEDBLOCKS'].fields_by_name['missed_blocks']._serialized_options = b'\310\336\037\000\362\336\037\024yaml:\"missed_blocks\"'
  _globals['_GENESISSTATE']._serialized_start=129
  _globals['_GENESISSTATE']._serialized_end=390
  _globals['_SIGNINGINFO']._serialized_start=393
  _globals['_SIGNINGINFO']._serialized_end=541
  _globals['_VALIDATORMISSEDBLOCKS']._serialized_start=544
  _globals['_VALIDATORMISSEDBLOCKS']._serialized_end=675
  _globals['_MISSEDBLOCK']._serialized_start=677
  _globals['_MISSEDBLOCK']._serialized_end=721
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/crucible/genesis.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/crucible/genesis.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from amino import amino_pb2 as amino_dot_amino__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from neurion.crucible import params_pb2 as neurion_dot_crucible_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eneurion/crucible/genesis.proto\x12\x10neurion.crucible\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\x1a\x1dneurion/crucible/params.proto\"C\n\x0cGenesisState\x12\x33\n\x06params\x18\x01 \x01(\x0b\x32\x18.neurion.crucible.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x42\x1aZ\x18neurion/x/crucible/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.crucible.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\030neurion/x/crucible/types'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISSTATE']._serialized_start=124
  _globals['_GENESISSTATE']._serialized_end=191
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class PubKey(_message.Message):
    __slots__ = ("key",)
    KEY_FIELD_NUMBER: _ClassVar[int]
    key: bytes
    def __init__(self, key: _Optional[bytes] = ...) -> None: ...

class PrivKey(_message.Message):
    __slots__ = ("secret",)
    SECRET_FIELD_NUMBER: _ClassVar[int]
    secret: bytes
    def __init__(self, secret: _Optional[bytes] = ...) -> None: ...



from cometbft.crypto.v1 import proof_pb2 as _proof_pb2
from cometbft.types.v1 import params_pb2 as _params_pb2
from cometbft.types.v1 import validator_pb2 as _validator_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CheckTxType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    CHECK_TX_TYPE_UNKNOWN: _ClassVar[CheckTxType]
    CHECK_TX_TYPE_RECHECK: _ClassVar[CheckTxType]
    CHECK_TX_TYPE_CHECK: _ClassVar[CheckTxType]

class OfferSnapshotResult(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    OFFER_SNAPSHOT_RESULT_UNKNOWN: _ClassVar[OfferSnapshotResult]
    OFFER_SNAPSHOT_RESULT_ACCEPT: _ClassVar[OfferSnapshotResult]
    OFFER_SNAPSHOT_RESULT_ABORT: _ClassVar[OfferSnapshotResult]
    OFFER_SNAPSHOT_RESULT_REJECT: _ClassVar[OfferSnapshotResult]
    OFFER_SNAPSHOT_RESULT_REJECT_FORMAT: _ClassVar[OfferSnapshotResult]
    OFFER_SNAPSHOT_RESULT_REJECT_SENDER: _ClassVar[OfferSnapshotResult]

class ApplySnapshotChunkResult(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    APPLY_SNAPSHOT_CHUNK_RESULT_UNKNOWN: _ClassVar[ApplySnapshotChunkResult]
    APPLY_SNAPSHOT_CHUNK_RESULT_ACCEPT: _ClassVar[ApplySnapshotChunkResult]
    APPLY_SNAPSHOT_CHUNK_RESULT_ABORT: _ClassVar[ApplySnapshotChunkResult]
    APPLY_SNAPSHOT_CHUNK_RESULT_RETRY: _ClassVar[ApplySnapshotChunkResult]
    APPLY_SNAPSHOT_CHUNK_RESULT_RETRY_SNAPSHOT: _ClassVar[ApplySnapshotChunkResult]
    APPLY_SNAPSHOT_CHUNK_RESULT_REJECT_SNAPSHOT: _ClassVar[ApplySnapshotChunkResult]

class ProcessProposalStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    PROCESS_PROPOSAL_STATUS_UNKNOWN: _ClassVar[ProcessProposalStatus]
    PROCESS_PROPOSAL_STATUS_ACCEPT: _ClassVar[ProcessProposalStatus]
    PROCESS_PROPOSAL_STATUS_REJECT: _ClassVar[ProcessProposalStatus]

class VerifyVoteExtensionStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    VERIFY_VOTE_EXTENSION_STATUS_UNKNOWN: _ClassVar[VerifyVoteExtensionStatus]
    VERIFY_VOTE_EXTENSION_STATUS_ACCEPT: _ClassVar[VerifyVoteExtensionStatus]
    VERIFY_VOTE_EXTENSION_STATUS_REJECT: _ClassVar[VerifyVoteExtensionStatus]

class MisbehaviorType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    MISBEHAVIOR_TYPE_UNKNOWN: _ClassVar[MisbehaviorType]
    MISBEHAVIOR_TYPE_DUPLICATE_VOTE: _ClassVar[MisbehaviorType]
    MISBEHAVIOR_TYPE_LIGHT_CLIENT_ATTACK: _ClassVar[MisbehaviorType]
CHECK_TX_TYPE_UNKNOWN: CheckTxType
CHECK_TX_TYPE_RECHECK: CheckTxType
CHECK_TX_TYPE_CHECK: CheckTxType
OFFER_SNAPSHOT_RESULT_UNKNOWN: OfferSnapshotResult
OFFER_SNAPSHOT_RESULT_ACCEPT: OfferSnapshotResult
OFFER_SNAPSHOT_RESULT_ABORT: OfferSnapshotResult
OFFER_SNAPSHOT_RESULT_REJECT: OfferSnapshotResult
OFFER_SNAPSHOT_RESULT_REJECT_FORMAT: OfferSnapshotResult
OFFER_SNAPSHOT_RESULT_REJECT_SENDER: OfferSnapshotResult
APPLY_SNAPSHOT_CHUNK_RESULT_UNKNOWN: ApplySnapshotChunkResult
APPLY_SNAPSHOT_CHUNK_RESULT_ACCEPT: ApplySnapshotChunkResult
APPLY_SNAPSHOT_CHUNK_RESULT_ABORT: ApplySnapshotChunkResult
APPLY_SNAPSHOT_CHUNK_RESULT_RETRY: ApplySnapshotChunkResult
APPLY_SNAPSHOT_CHUNK_RESULT_RETRY_SNAPSHOT: ApplySnapshotChunkResult
APPLY_SNAPSHOT_CHUNK_RESULT_REJECT_SNAPSHOT: ApplySnapshotChunkResult
PROCESS_PROPOSAL_STATUS_UNKNOWN: ProcessProposalStatus
PROCESS_PROPOSAL_STATUS_ACCEPT: ProcessProposalStatus
PROCESS_PROPOSAL_STATUS_REJECT: ProcessProposalStatus
VERIFY_VOTE_EXTENSION_STATUS_UNKNOWN: VerifyVoteExtensionStatus
VERIFY_VOTE_EXTENSION_STATUS_ACCEPT: VerifyVoteExtensionStatus
VERIFY_VOTE_EXTENSION_STATUS_REJECT: VerifyVoteExtensionStatus
MISBEHAVIOR_TYPE_UNKNOWN: MisbehaviorType
MISBEHAVIOR_TYPE_DUPLICATE_VOTE: MisbehaviorType
MISBEHAVIOR_TYPE_LIGHT_CLIENT_ATTACK: MisbehaviorType

class Request(_message.Message):
    __slots__ = ("echo", "flush", "info", "init_chain", "query", "check_tx", "commit", "list_snapshots", "offer_snapshot", "load_snapshot_chunk", "apply_snapshot_chunk", "prepare_proposal", "process_proposal", "extend_vote", "verify_vote_extension", "finalize_block")
    ECHO_FIELD_NUMBER: _ClassVar[int]
    FLUSH_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    INIT_CHAIN_FIELD_NUMBER: _ClassVar[int]
    QUERY_FIELD_NUMBER: _ClassVar[int]
    CHECK_TX_FIELD_NUMBER: _ClassVar[int]
    COMMIT_FIELD_NUMBER: _ClassVar[int]
    LIST_SNAPSHOTS_FIELD_NUMBER: _ClassVar[int]
    OFFER_SNAPSHOT_FIELD_NUMBER: _ClassVar[int]
    LOAD_SNAPSHOT_CHUNK_FIELD_NUMBER: _ClassVar[int]
    APPLY_SNAPSHOT_CHUNK_FIELD_NUMBER: _ClassVar[int]
    PREPARE_PROPOSAL_FIELD_NUMBER: _ClassVar[int]
    PROCESS_PROPOSAL_FIELD_NUMBER: _ClassVar[int]
    EXTEND_VOTE_FIELD_NUMBER: _ClassVar[int]
    VERIFY_VOTE_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    FINALIZE_BLOCK_FIELD_NUMBER: _ClassVar[int]
    echo: EchoRequest
    flush: FlushRequest
    info: InfoRequest
    init_chain: InitChainRequest
    query: QueryRequest
    check_tx: CheckTxRequest
    commit: CommitRequest
    list_snapshots: ListSnapshotsRequest
    offer_snapshot: OfferSnapshotRequest
    load_snapshot_chunk: LoadSnapshotChunkRequest
    apply_snapshot_chunk: ApplySnapshotChunkRequest
    prepare_proposal: PrepareProposalRequest
    process_proposal: ProcessProposalRequest
    extend_vote: ExtendVoteRequest
    verify_vote_extension: VerifyVoteExtensionRequest
    finalize_block: FinalizeBlockRequest
    def __init__(self, echo: _Optional[_Union[EchoRequest, _Mapping]] = ..., flush: _Optional[_Union[FlushRequest, _Mapping]] = ..., info: _Optional[_Union[InfoRequest, _Mapping]] = ..., init_chain: _Optional[_Union[InitChainRequest, _Mapping]] = ..., query: _Optional[_Union[QueryRequest, _Mapping]] = ..., check_tx: _Optional[_Union[CheckTxRequest, _Mapping]] = ..., commit: _Optional[_Union[CommitRequest, _Mapping]] = ..., list_snapshots: _Optional[_Union[ListSnapshotsRequest, _Mapping]] = ..., offer_snapshot: _Optional[_Union[OfferSnapshotRequest, _Mapping]] = ..., load_snapshot_chunk: _Optional[_Union[LoadSnapshotChunkRequest, _Mapping]] = ..., apply_snapshot_chunk: _Optional[_Union[ApplySnapshotChunkRequest, _Mapping]] = ..., prepare_proposal: _Optional[_Union[PrepareProposalRequest, _Mapping]] = ..., process_proposal: _Optional[_Union[ProcessProposalRequest, _Mapping]] = ..., extend_vote: _Optional[_Union[ExtendVoteRequest, _Mapping]] = ..., verify_vote_extension: _Optional[_Union[VerifyVoteExtensionRequest, _Mapping]] = ..., finalize_block: _Optional[_Union[FinalizeBlockRequest, _Mapping]] = ...) -> None: ...

class EchoRequest(_message.Message):
    __slots__ = ("message",)
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    message: str
    def __init__(self, message: _Optional[str] = ...) -> None: ...

class FlushRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class InfoRequest(_message.Message):
    __slots__ = ("version", "block_version", "p2p_version", "abci_version")
    VERSION_FIELD_NUMBER: _ClassVar[int]
    BLOCK_VERSION_FIELD_NUMBER: _ClassVar[int]
    P2P_VERSION_FIELD_NUMBER: _ClassVar[int]
    ABCI_VERSION_FIELD_NUMBER: _ClassVar[int]
    version: str
    block_version: int
    p2p_version: int
    abci_version: str
    def __init__(self, version: _Optional[str] = ..., block_version: _Optional[int] = ..., p2p_version: _Optional[int] = ..., abci_version: _Optional[str] = ...) -> None: ...

class InitChainRequest(_message.Message):
    __slots__ = ("time", "chain_id", "consensus_params", "validators", "app_state_bytes", "initial_height")
    TIME_FIELD_NUMBER: _ClassVar[int]
    CHAIN_ID_FIELD_NUMBER: _ClassVar[int]
    CONSENSUS_PARAMS_FIELD_NUMBER: _ClassVar[int]
    VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    APP_STATE_BYTES_FIELD_NUMBER: _ClassVar[int]
    INITIAL_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    time: _timestamp_pb2.Timestamp
    chain_id: str
    consensus_params: _params_pb2.ConsensusParams
    validators: _containers.RepeatedCompositeFieldContainer[ValidatorUpdate]
    app_state_bytes: bytes
    initial_height: int
    def __init__(self, time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., chain_id: _Optional[str] = ..., consensus_params: _Optional[_Union[_params_pb2.ConsensusParams, _Mapping]] = ..., validators: _Optional[_Iterable[_Union[ValidatorUpdate, _Mapping]]] = ..., app_state_bytes: _Optional[bytes] = ..., initial_height: _Optional[int] = ...) -> None: ...

class QueryRequest(_message.Message):
    __slots__ = ("data", "path", "height", "prove")
    DATA_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    PROVE_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    path: str
    height: int
    prove: bool
    def __init__(self, data: _Optional[bytes] = ..., path: _Optional[str] = ..., height: _Optional[int] = ..., prove: bool = ...) -> None: ...

class CheckTxRequest(_message.Message):
    __slots__ = ("tx", "type")
    TX_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    tx: bytes
    type: CheckTxType
    def __init__(self, tx: _Optional[bytes] = ..., type: _Optional[_Union[CheckTxType, str]] = ...) -> None: ...

class CommitRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListSnapshotsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class OfferSnapshotRequest(_message.Message):
    __slots__ = ("snapshot", "app_hash")
    SNAPSHOT_FIELD_NUMBER: _ClassVar[int]
    APP_HASH_FIELD_NUMBER: _ClassVar[int]
    snapshot: Snapshot
    app_hash: bytes
    def __init__(self, snapshot: _Optional[_Union[Snapshot, _Mapping]] = ..., app_hash: _Optional[bytes] = ...) -> None: ...

class LoadSnapshotChunkRequest(_message.Message):
    __slots__ = ("height", "format", "chunk")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    CHUNK_FIELD_NUMBER: _ClassVar[int]
    height: int
    format: int
    chunk: int
    def __init__(self, height: _Optional[int] = ..., format: _Optional[int] = ..., chunk: _Optional[int] = ...) -> None: ...

class ApplySnapshotChunkRequest(_message.Message):
    __slots__ = ("index", "chunk", "sender")
    INDEX_FIELD_NUMBER: _ClassVar[int]
    CHUNK_FIELD_NUMBER: _ClassVar[int]
    SENDER_FIELD_NUMBER: _ClassVar[int]
    index: int
    chunk: bytes
    sender: str
    def __init__(self, index: _Optional[int] = ..., chunk: _Optional[bytes] = ..., sender: _Optional[str] = ...) -> None: ...

class PrepareProposalRequest(_message.Message):
    __slots__ = ("max_tx_bytes", "txs", "local_last_commit", "misbehavior", "height", "time", "next_validators_hash", "proposer_address")
    MAX_TX_BYTES_FIELD_NUMBER: _ClassVar[int]
    TXS_FIELD_NUMBER: _ClassVar[int]
    LOCAL_LAST_COMMIT_FIELD_NUMBER: _ClassVar[int]
    MISBEHAVIOR_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TIME_FIELD_NUMBER: _ClassVar[int]
    NEXT_VALIDATORS_HASH_FIELD_NUMBER: _ClassVar[int]
    PROPOSER_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    max_tx_bytes: int
    txs: _containers.RepeatedScalarFieldContainer[bytes]
    local_last_commit: ExtendedCommitInfo
    misbehavior: _containers.RepeatedCompositeFieldContainer[Misbehavior]
    height: int
    time: _timestamp_pb2.Timestamp
    next_validators_hash: bytes
    proposer_address: bytes
    def __init__(self, max_tx_bytes: _Optional[int] = ..., txs: _Optional[_Iterable[bytes]] = ..., local_last_commit: _Optional[_Union[ExtendedCommitInfo, _Mapping]] = ..., misbehavior: _Optional[_Iterable[_Union[Misbehavior, _Mapping]]] = ..., height: _Optional[int] = ..., time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., next_validators_hash: _Optional[bytes] = ..., proposer_address: _Optional[bytes] = ...) -> None: ...

class ProcessProposalRequest(_message.Message):
    __slots__ = ("txs", "proposed_last_commit", "misbehavior", "hash", "height", "time", "next_validators_hash", "proposer_address")
    TXS_FIELD_NUMBER: _ClassVar[int]
    PROPOSED_LAST_COMMIT_FIELD_NUMBER: _ClassVar[int]
    MISBEHAVIOR_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TIME_FIELD_NUMBER: _ClassVar[int]
    NEXT_VALIDATORS_HASH_FIELD_NUMBER: _ClassVar[int]
    PROPOSER_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    txs: _containers.RepeatedScalarFieldContainer[bytes]
    proposed_last_commit: CommitInfo
    misbehavior: _containers.RepeatedCompositeFieldContainer[Misbehavior]
    hash: bytes
    height: int
    time: _timestamp_pb2.Timestamp
    next_validators_hash: bytes
    proposer_address: bytes
    def __init__(self, txs: _Optional[_Iterable[bytes]] = ..., proposed_last_commit: _Optional[_Union[CommitInfo, _Mapping]] = ..., misbehavior: _Optional[_Iterable[_Union[Misbehavior, _Mapping]]] = ..., hash: _Optional[bytes] = ..., height: _Optional[int] = ..., time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., next_validators_hash: _Optional[bytes] = ..., proposer_address: _Optional[bytes] = ...) -> None: ...

class ExtendVoteRequest(_message.Message):
    __slots__ = ("hash", "height", "time", "txs", "proposed_last_commit", "misbehavior", "next_validators_hash", "proposer_address")
    HASH_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TIME_FIELD_NUMBER: _ClassVar[int]
    TXS_FIELD_NUMBER: _ClassVar[int]
    PROPOSED_LAST_COMMIT_FIELD_NUMBER: _ClassVar[int]
    MISBEHAVIOR_FIELD_NUMBER: _ClassVar[int]
    NEXT_VALIDATORS_HASH_FIELD_NUMBER: _ClassVar[int]
    PROPOSER_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    hash: bytes
    height: int
    time: _timestamp_pb2.Timestamp
    txs: _containers.RepeatedScalarFieldContainer[bytes]
    proposed_last_commit: CommitInfo
    misbehavior: _containers.RepeatedCompositeFieldContainer[Misbehavior]
    next_validators_hash: bytes
    proposer_address: bytes
    def __init__(self, hash: _Optional[bytes] = ..., height: _Optional[int] = ..., time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., txs: _Optional[_Iterable[bytes]] = ..., proposed_last_commit: _Optional[_Union[CommitInfo, _Mapping]] = ..., misbehavior: _Optional[_Iterable[_Union[Misbehavior, _Mapping]]] = ..., next_validators_hash: _Optional[bytes] = ..., proposer_address: _Optional[bytes] = ...) -> None: ...

class VerifyVoteExtensionRequest(_message.Message):
    __slots__ = ("hash", "validator_address", "height", "vote_extension")
    HASH_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    VOTE_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    hash: bytes
    validator_address: bytes
    height: int
    vote_extension: bytes
    def __init__(self, hash: _Optional[bytes] = ..., validator_address: _Optional[bytes] = ..., height: _Optional[int] = ..., vote_extension: _Optional[bytes] = ...) -> None: ...

class FinalizeBlockRequest(_message.Message):
    __slots__ = ("txs", "decided_last_commit", "misbehavior", "hash", "height", "time", "next_validators_hash", "proposer_address", "syncing_to_height")
    TXS_FIELD_NUMBER: _ClassVar[int]
    DECIDED_LAST_COMMIT_FIELD_NUMBER: _ClassVar[int]
    MISBEHAVIOR_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TIME_FIELD_NUMBER: _ClassVar[int]
    NEXT_VALIDATORS_HASH_FIELD_NUMBER: _ClassVar[int]
    PROPOSER_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    SYNCING_TO_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    txs: _containers.RepeatedScalarFieldContainer[bytes]
    decided_last_commit: CommitInfo
    misbehavior: _containers.RepeatedCompositeFieldContainer[Misbehavior]
    hash: bytes
    height: int
    time: _timestamp_pb2.Timestamp
    next_validators_hash: bytes
    proposer_address: bytes
    syncing_to_height: int
    def __init__(self, txs: _Optional[_Iterable[bytes]] = ..., decided_last_commit: _Optional[_Union[CommitInfo, _Mapping]] = ..., misbehavior: _Optional[_Iterable[_Union[Misbehavior, _Mapping]]] = ..., hash: _Optional[bytes] = ..., height: _Optional[int] = ..., time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., next_validators_hash: _Optional[bytes] = ..., proposer_address: _Optional[bytes] = ..., syncing_to_height: _Optional[int] = ...) -> None: ...

class Response(_message.Message):
    __slots__ = ("exception", "echo", "flush", "info", "init_chain", "query", "check_tx", "commit", "list_snapshots", "offer_snapshot", "load_snapshot_chunk", "apply_snapshot_chunk", "prepare_proposal", "process_proposal", "extend_vote", "verify_vote_extension", "finalize_block")
    EXCEPTION_FIELD_NUMBER: _ClassVar[int]
    ECHO_FIELD_NUMBER: _ClassVar[int]
    FLUSH_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    INIT_CHAIN_FIELD_NUMBER: _ClassVar[int]
    QUERY_FIELD_NUMBER: _ClassVar[int]
    CHECK_TX_FIELD_NUMBER: _ClassVar[int]
    COMMIT_FIELD_NUMBER: _ClassVar[int]
    LIST_SNAPSHOTS_FIELD_NUMBER: _ClassVar[int]
    OFFER_SNAPSHOT_FIELD_NUMBER: _ClassVar[int]
    LOAD_SNAPSHOT_CHUNK_FIELD_NUMBER: _ClassVar[int]
    APPLY_SNAPSHOT_CHUNK_FIELD_NUMBER: _ClassVar[int]
    PREPARE_PROPOSAL_FIELD_NUMBER: _ClassVar[int]
    PROCESS_PROPOSAL_FIELD_NUMBER: _ClassVar[int]
    EXTEND_VOTE_FIELD_NUMBER: _ClassVar[int]
    VERIFY_VOTE_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    FINALIZE_BLOCK_FIELD_NUMBER: _ClassVar[int]
    exception: ExceptionResponse
    echo: EchoResponse
    flush: FlushResponse
    info: InfoResponse
    init_chain: InitChainResponse
    query: QueryResponse
    check_tx: CheckTxResponse
    commit: CommitResponse
    list_snapshots: ListSnapshotsResponse
    offer_snapshot: OfferSnapshotResponse
    load_snapshot_chunk: LoadSnapshotChunkResponse
    apply_snapshot_chunk: ApplySnapshotChunkResponse
    prepare_proposal: PrepareProposalResponse
    process_proposal: ProcessProposalResponse
    extend_vote: ExtendVoteResponse
    verify_vote_extension: VerifyVoteExtensionResponse
    finalize_block: FinalizeBlockResponse
    def __init__(self, exception: _Optional[_Union[ExceptionResponse, _Mapping]] = ..., echo: _Optional[_Union[EchoResponse, _Mapping]] = ..., flush: _Optional[_Union[FlushResponse, _Mapping]] = ..., info: _Optional[_Union[InfoResponse, _Mapping]] = ..., init_chain: _Optional[_Union[InitChainResponse, _Mapping]] = ..., query: _Optional[_Union[QueryResponse, _Mapping]] = ..., check_tx: _Optional[_Union[CheckTxResponse, _Mapping]] = ..., commit: _Optional[_Union[CommitResponse, _Mapping]] = ..., list_snapshots: _Optional[_Union[ListSnapshotsResponse, _Mapping]] = ..., offer_snapshot: _Optional[_Union[OfferSnapshotResponse, _Mapping]] = ..., load_snapshot_chunk: _Optional[_Union[LoadSnapshotChunkResponse, _Mapping]] = ..., apply_snapshot_chunk: _Optional[_Union[ApplySnapshotChunkResponse, _Mapping]] = ..., prepare_proposal: _Optional[_Union[PrepareProposalResponse, _Mapping]] = ..., process_proposal: _Optional[_Union[ProcessProposalResponse, _Mapping]] = ..., extend_vote: _Optional[_Union[ExtendVoteResponse, _Mapping]] = ..., verify_vote_extension: _Optional[_Union[VerifyVoteExtensionResponse, _Mapping]] = ..., finalize_block: _Optional[_Union[FinalizeBlockResponse, _Mapping]] = ...) -> None: ...

class ExceptionResponse(_message.Message):
    __slots__ = ("error",)
    ERROR_FIELD_NUMBER: _ClassVar[int]
    error: str
    def __init__(self, error: _Optional[str] = ...) -> None: ...

class EchoResponse(_message.Message):
    __slots__ = ("message",)
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    message: str
    def __init__(self, message: _Optional[str] = ...) -> None: ...

class FlushResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class InfoResponse(_message.Message):
    __slots__ = ("data", "version", "app_version", "last_block_height", "last_block_app_hash", "lane_priorities", "default_lane")
    class LanePrioritiesEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: int
        def __init__(self, key: _Optional[str] = ..., value: _Optional[int] = ...) -> None: ...
    DATA_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    APP_VERSION_FIELD_NUMBER: _ClassVar[int]
    LAST_BLOCK_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    LAST_BLOCK_APP_HASH_FIELD_NUMBER: _ClassVar[int]
    LANE_PRIORITIES_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_LANE_FIELD_NUMBER: _ClassVar[int]
    data: str
    version: str
    app_version: int
    last_block_height: int
    last_block_app_hash: bytes
    lane_priorities: _containers.ScalarMap[str, int]
    default_lane: str
    def __init__(self, data: _Optional[str] = ..., version: _Optional[str] = ..., app_version: _Optional[int] = ..., last_block_height: _Optional[int] = ..., last_block_app_hash: _Optional[bytes] = ..., lane_priorities: _Optional[_Mapping[str, int]] = ..., default_lane: _Optional[str] = ...) -> None: ...

class InitChainResponse(_message.Message):
    __slots__ = ("consensus_params", "validators", "app_hash")
    CONSENSUS_PARAMS_FIELD_NUMBER: _ClassVar[int]
    VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    APP_HASH_FIELD_NUMBER: _ClassVar[int]
    consensus_params: _params_pb2.ConsensusParams
    validators: _containers.RepeatedCompositeFieldContainer[ValidatorUpdate]
    app_hash: bytes
    def __init__(self, consensus_params: _Optional[_Union[_params_pb2.ConsensusParams, _Mapping]] = ..., validators: _Optional[_Iterable[_Union[ValidatorUpdate, _Mapping]]] = ..., app_hash: _Optional[bytes] = ...) -> None: ...

class QueryResponse(_message.Message):
    __slots__ = ("code", "log", "info", "index", "key", "value", "proof_ops", "height", "codespace")
    CODE_FIELD_NUMBER: _ClassVar[int]
    LOG_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    PROOF_OPS_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    CODESPACE_FIELD_NUMBER: _ClassVar[int]
    code: int
    log: str
    info: str
    index: int
    key: bytes
    value: bytes
    proof_ops: _proof_pb2.ProofOps
    height: int
    codespace: str
    def __init__(self, code: _Optional[int] = ..., log: _Optional[str] = ..., info: _Optional[str] = ..., index: _Optional[int] = ..., key: _Optional[bytes] = ..., value: _Optional[bytes] = ..., proof_ops: _Optional[_Union[_proof_pb2.ProofOps, _Mapping]] = ..., height: _Optional[int] = ..., codespace: _Optional[str] = ...) -> None: ...

class CheckTxResponse(_message.Message):
    __slots__ = ("code", "data", "log", "info", "gas_wanted", "gas_used", "events", "codespace", "lane_id")
    CODE_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    LOG_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    GAS_WANTED_FIELD_NUMBER: _ClassVar[int]
    GAS_USED_FIELD_NUMBER: _ClassVar[int]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    CODESPACE_FIELD_NUMBER: _ClassVar[int]
    LANE_ID_FIELD_NUMBER: _ClassVar[int]
    code: int
    data: bytes
    log: str
    info: str
    gas_wanted: int
    gas_used: int
    events: _containers.RepeatedCompositeFieldContainer[Event]
    codespace: str
    lane_id: str
    def __init__(self, code: _Optional[int] = ..., data: _Optional[bytes] = ..., log: _Optional[str] = ..., info: _Optional[str] = ..., gas_wanted: _Optional[int] = ..., gas_used: _Optional[int] = ..., events: _Optional[_Iterable[_Union[Event, _Mapping]]] = ..., codespace: _Optional[str] = ..., lane_id: _Optional[str] = ...) -> None: ...

class CommitResponse(_message.Message):
    __slots__ = ("retain_height",)
    RETAIN_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    retain_height: int
    def __init__(self, retain_height: _Optional[int] = ...) -> None: ...

class ListSnapshotsResponse(_message.Message):
    __slots__ = ("snapshots",)
    SNAPSHOTS_FIELD_NUMBER: _ClassVar[int]
    snapshots: _containers.RepeatedCompositeFieldContainer[Snapshot]
    def __init__(self, snapshots: _Optional[_Iterable[_Union[Snapshot, _Mapping]]] = ...) -> None: ...

class OfferSnapshotResponse(_message.Message):
    __slots__ = ("result",)
    RESULT_FIELD_NUMBER: _ClassVar[int]
    result: OfferSnapshotResult
    def __init__(self, result: _Optional[_Union[OfferSnapshotResult, str]] = ...) -> None: ...

class LoadSnapshotChunkResponse(_message.Message):
    __slots__ = ("chunk",)
    CHUNK_FIELD_NUMBER: _ClassVar[int]
    chunk: bytes
    def __init__(self, chunk: _Optional[bytes] = ...) -> None: ...

class ApplySnapshotChunkResponse(_message.Message):
    __slots__ = ("result", "refetch_chunks", "reject_senders")
    RESULT_FIELD_NUMBER: _ClassVar[int]
    REFETCH_CHUNKS_FIELD_NUMBER: _ClassVar[int]
    REJECT_SENDERS_FIELD_NUMBER: _ClassVar[int]
    result: ApplySnapshotChunkResult
    refetch_chunks: _containers.RepeatedScalarFieldContainer[int]
    reject_senders: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, result: _Optional[_Union[ApplySnapshotChunkResult, str]] = ..., refetch_chunks: _Optional[_Iterable[int]] = ..., reject_senders: _Optional[_Iterable[str]] = ...) -> None: ...

class PrepareProposalResponse(_message.Message):
    __slots__ = ("txs",)
    TXS_FIELD_NUMBER: _ClassVar[int]
    txs: _containers.RepeatedScalarFieldContainer[bytes]
    def __init__(self, txs: _Optional[_Iterable[bytes]] = ...) -> None: ...

class ProcessProposalResponse(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: ProcessProposalStatus
    def __init__(self, status: _Optional[_Union[ProcessProposalStatus, str]] = ...) -> None: ...

class ExtendVoteResponse(_message.Message):
    __slots__ = ("vote_extension",)
    VOTE_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    vote_extension: bytes
    def __init__(self, vote_extension: _Optional[bytes] = ...) -> None: ...

class VerifyVoteExtensionResponse(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: VerifyVoteExtensionStatus
    def __init__(self, status: _Optional[_Union[VerifyVoteExtensionStatus, str]] = ...) -> None: ...

class FinalizeBlockResponse(_message.Message):
    __slots__ = ("events", "tx_results", "validator_updates", "consensus_param_updates", "app_hash", "next_block_delay")
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    TX_RESULTS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_UPDATES_FIELD_NUMBER: _ClassVar[int]
    CONSENSUS_PARAM_UPDATES_FIELD_NUMBER: _ClassVar[int]
    APP_HASH_FIELD_NUMBER: _ClassVar[int]
    NEXT_BLOCK_DELAY_FIELD_NUMBER: _ClassVar[int]
    events: _containers.RepeatedCompositeFieldContainer[Event]
    tx_results: _containers.RepeatedCompositeFieldContainer[ExecTxResult]
    validator_updates: _containers.RepeatedCompositeFieldContainer[ValidatorUpdate]
    consensus_param_updates: _params_pb2.ConsensusParams
    app_hash: bytes
    next_block_delay: _duration_pb2.Duration
    def __init__(self, events: _Optional[_Iterable[_Union[Event, _Mapping]]] = ..., tx_results: _Optional[_Iterable[_Union[ExecTxResult, _Mapping]]] = ..., validator_updates: _Optional[_Iterable[_Union[ValidatorUpdate, _Mapping]]] = ..., consensus_param_updates: _Optional[_Union[_params_pb2.ConsensusParams, _Mapping]] = ..., app_hash: _Optional[bytes] = ..., next_block_delay: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...

class CommitInfo(_message.Message):
    __slots__ = ("round", "votes")
    ROUND_FIELD_NUMBER: _ClassVar[int]
    VOTES_FIELD_NUMBER: _ClassVar[int]
    round: int
    votes: _containers.RepeatedCompositeFieldContainer[VoteInfo]
    def __init__(self, round: _Optional[int] = ..., votes: _Optional[_Iterable[_Union[VoteInfo, _Mapping]]] = ...) -> None: ...

class ExtendedCommitInfo(_message.Message):
    __slots__ = ("round", "votes")
    ROUND_FIELD_NUMBER: _ClassVar[int]
    VOTES_FIELD_NUMBER: _ClassVar[int]
    round: int
    votes: _containers.RepeatedCompositeFieldContainer[ExtendedVoteInfo]
    def __init__(self, round: _Optional[int] = ..., votes: _Optional[_Iterable[_Union[ExtendedVoteInfo, _Mapping]]] = ...) -> None: ...

class Event(_message.Message):
    __slots__ = ("type", "attributes")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    type: str
    attributes: _containers.RepeatedCompositeFieldContainer[EventAttribute]
    def __init__(self, type: _Optional[str] = ..., attributes: _Optional[_Iterable[_Union[EventAttribute, _Mapping]]] = ...) -> None: ...

class EventAttribute(_message.Message):
    __slots__ = ("key", "value", "index")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: str
    index: bool
    def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ..., index: bool = ...) -> None: ...

class ExecTxResult(_message.Message):
    __slots__ = ("code", "data", "log", "info", "gas_wanted", "gas_used", "events", "codespace")
    CODE_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    LOG_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    GAS_WANTED_FIELD_NUMBER: _ClassVar[int]
    GAS_USED_FIELD_NUMBER: _ClassVar[int]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    CODESPACE_FIELD_NUMBER: _ClassVar[int]
    code: int
    data: bytes
    log: str
    info: str
    gas_wanted: int
    gas_used: int
    events: _containers.RepeatedCompositeFieldContainer[Event]
    codespace: str
    def __init__(self, code: _Optional[int] = ..., data: _Optional[bytes] = ..., log: _Optional[str] = ..., info: _Optional[str] = ..., gas_wanted: _Optional[int] = ..., gas_used: _Optional[int] = ..., events: _Optional[_Iterable[_Union[Event, _Mapping]]] = ..., codespace: _Optional[str] = ...) -> None: ...

class TxResult(_message.Message):
    __slots__ = ("height", "index", "tx", "result")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    TX_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    height: int
    index: int
    tx: bytes
    result: ExecTxResult
    def __init__(self, height: _Optional[int] = ..., index: _Optional[int] = ..., tx: _Optional[bytes] = ..., result: _Optional[_Union[ExecTxResult, _Mapping]] = ...) -> None: ...

class Validator(_message.Message):
    __slots__ = ("address", "power")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    POWER_FIELD_NUMBER: _ClassVar[int]
    address: bytes
    power: int
    def __init__(self, address: _Optional[bytes] = ..., power: _Optional[int] = ...) -> None: ...

class ValidatorUpdate(_message.Message):
    __slots__ = ("power", "pub_key_bytes", "pub_key_type")
    POWER_FIELD_NUMBER: _ClassVar[int]
    PUB_KEY_BYTES_FIELD_NUMBER: _ClassVar[int]
    PUB_KEY_TYPE_FIELD_NUMBER: _ClassVar[int]
    power: int
    pub_key_bytes: bytes
    pub_key_type: str
    def __init__(self, power: _Optional[int] = ..., pub_key_bytes: _Optional[bytes] = ..., pub_key_type: _Optional[str] = ...) -> None: ...

class VoteInfo(_message.Message):
    __slots__ = ("validator", "block_id_flag")
    VALIDATOR_FIELD_NUMBER: _ClassVar[int]
    BLOCK_ID_FLAG_FIELD_NUMBER: _ClassVar[int]
    validator: Validator
    block_id_flag: _validator_pb2.BlockIDFlag
    def __init__(self, validator: _Optional[_Union[Validator, _Mapping]] = ..., block_id_flag: _Optional[_Union[_validator_pb2.BlockIDFlag, str]] = ...) -> None: ...

class ExtendedVoteInfo(_message.Message):
    __slots__ = ("validator", "vote_extension", "extension_signature", "block_id_flag")
    VALIDATOR_FIELD_NUMBER: _ClassVar[int]
    VOTE_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    EXTENSION_SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    BLOCK_ID_FLAG_FIELD_NUMBER: _ClassVar[int]
    validator: Validator
    vote_extension: bytes
    extension_signature: bytes
    block_id_flag: _validator_pb2.BlockIDFlag
    def __init__(self, validator: _Optional[_Union[Validator, _Mapping]] = ..., vote_extension: _Optional[bytes] = ..., extension_signature: _Optional[bytes] = ..., block_id_flag: _Optional[_Union[_validator_pb2.BlockIDFlag, str]] = ...) -> None: ...

class Misbehavior(_message.Message):
    __slots__ = ("type", "validator", "height", "time", "total_voting_power")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TIME_FIELD_NUMBER: _ClassVar[int]
    TOTAL_VOTING_POWER_FIELD_NUMBER: _ClassVar[int]
    type: MisbehaviorType
    validator: Validator
    height: int
    time: _timestamp_pb2.Timestamp
    total_voting_power: int
    def __init__(self, type: _Optional[_Union[MisbehaviorType, str]] = ..., validator: _Optional[_Union[Validator, _Mapping]] = ..., height: _Optional[int] = ..., time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., total_voting_power: _Optional[int] = ...) -> None: ...

class Snapshot(_message.Message):
    __slots__ = ("height", "format", "chunks", "hash", "metadata")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    CHUNKS_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    height: int
    format: int
    chunks: int
    hash: bytes
    metadata: bytes
    def __init__(self, height: _Optional[int] = ..., format: _Optional[int] = ..., chunks: _Optional[int] = ..., hash: _Optional[bytes] = ..., metadata: _Optional[bytes] = ...) -> None: ...
